@@ -14,18 +14,6 @@
 #ifndef LLVM_CONFIG_H
 #define LLVM_CONFIG_H
 
-/*
- * When bsd.lib.mk builds shared libraries it builds with -DPIC which 
- * causes problems in the following files which use PIC as a variable name.
- * undefine PIC here to minimise the diff to upstream LLVM
- *
- * include/llvm/MC/MCObjectFileInfo.h
- * lib/MC/MCObjectFileInfo.cpp
- * lib/Transforms/Scalar/LICM.cpp
- * lib/Transforms/Utils/PredicateInfo.cpp
- */
-#undef PIC
-
 /* Define if LLVM_ENABLE_DUMP is enabled */
 /* #undef LLVM_ENABLE_DUMP */
 
@@ -33,7 +21,7 @@
 /* #undef LINK_POLLY_INTO_TOOLS */
 
 /* Target triple LLVM will generate code for by default */
-#define LLVM_DEFAULT_TARGET_TRIPLE "mips64el-unknown-openbsd6.5"
+#define LLVM_DEFAULT_TARGET_TRIPLE "armv7-unknown-netbsdelf8.99-eabihf"
 
 /* Define if threads enabled */
 #define LLVM_ENABLE_THREADS 1
@@ -42,28 +30,28 @@
 #define LLVM_HAS_ATOMICS 1
 
 /* Host triple LLVM will be executed on */
-#define LLVM_HOST_TRIPLE "mips64el-unknown-openbsd6.5"
+#define LLVM_HOST_TRIPLE "armv7-unknown-netbsdelf8.99-eabihf"
 
 /* LLVM architecture name for the native architecture, if available */
-#define LLVM_NATIVE_ARCH Mips
+#define LLVM_NATIVE_ARCH ARM
 
 /* LLVM name for the native AsmParser init function, if available */
-#define LLVM_NATIVE_ASMPARSER LLVMInitializeMipsAsmParser
+#define LLVM_NATIVE_ASMPARSER LLVMInitializeARMAsmParser
 
 /* LLVM name for the native AsmPrinter init function, if available */
-#define LLVM_NATIVE_ASMPRINTER LLVMInitializeMipsAsmPrinter
+#define LLVM_NATIVE_ASMPRINTER LLVMInitializeARMAsmPrinter
 
 /* LLVM name for the native Disassembler init function, if available */
-#define LLVM_NATIVE_DISASSEMBLER LLVMInitializeMipsDisassembler
+#define LLVM_NATIVE_DISASSEMBLER LLVMInitializeARMDisassembler
 
 /* LLVM name for the native Target init function, if available */
-#define LLVM_NATIVE_TARGET LLVMInitializeMipsTarget
+#define LLVM_NATIVE_TARGET LLVMInitializeARMTarget
 
 /* LLVM name for the native TargetInfo init function, if available */
-#define LLVM_NATIVE_TARGETINFO LLVMInitializeMipsTargetInfo
+#define LLVM_NATIVE_TARGETINFO LLVMInitializeARMTargetInfo
 
 /* LLVM name for the native target MC init function, if available */
-#define LLVM_NATIVE_TARGETMC LLVMInitializeMipsTargetMC
+#define LLVM_NATIVE_TARGETMC LLVMInitializeARMTargetMC
 
 /* Define if this is Unixish platform */
 #define LLVM_ON_UNIX 1
@@ -78,16 +66,16 @@
 #define LLVM_USE_PERF 0
 
 /* Major version of the LLVM API */
-#define LLVM_VERSION_MAJOR 7
+#define LLVM_VERSION_MAJOR 8
 
 /* Minor version of the LLVM API */
 #define LLVM_VERSION_MINOR 0
 
 /* Patch version of the LLVM API */
-#define LLVM_VERSION_PATCH 1
+#define LLVM_VERSION_PATCH 0
 
 /* LLVM version string */
-#define LLVM_VERSION_STRING "7.0.1"
+#define LLVM_VERSION_STRING "8.0.0"
 
 /* Whether LLVM records statistics for use with GetStatistics(),
  * PrintStatistics() or PrintStatisticsJSON()
